<?php
/**
 * Copyright ©  All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Pinpoint\CarouselManager\Controller\Adminhtml\Carousel;

use Pinpoint\CarouselManager\Model\CarouselFactory;
use Pinpoint\CarouselManager\Model\SlideRepository;

class Edit extends \Pinpoint\CarouselManager\Controller\Adminhtml\Carousel
{

    protected $resultPageFactory;
    /**
     * @var SlideRepository
     */
    private $slideRepository;
    /**
     * @var CarouselFactory
     */
    private $carouselFactory;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\Registry $coreRegistry
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\Registry $coreRegistry,
        SlideRepository $slideRepository,
        CarouselFactory $carouselFactory,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->slideRepository = $slideRepository;
        $this->carouselFactory = $carouselFactory;
        parent::__construct($context, $coreRegistry);
    }

    /**
     * Edit action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        // 1. Get ID and create model
        $id = $this->getRequest()->getParam('carousel_id');
        $model = $this->carouselFactory->create();
        $slides = [];

        // 2. Initial checking
        if ($id) {
            $model->load($id);
            if (!$model->getId()) {
                $this->messageManager->addErrorMessage(__('This Carousel no longer exists.'));
                /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
                $resultRedirect = $this->resultRedirectFactory->create();
                return $resultRedirect->setPath('*/*/');
            }

            $slides = $this->slideRepository->getByCarouselId($id);

        }
        $this->_coreRegistry->register('pinpoint_carouselmanager_carousel', $model);
        $this->_coreRegistry->register('pinpoint_carouselmanager_carousel_slides', $slides);

        // 3. Build edit form
        /** @var \Magento\Backend\Model\View\Result\Page $resultPage */
        $resultPage = $this->resultPageFactory->create();
        $this->initPage($resultPage)->addBreadcrumb(
            $id ? __('Edit Carousel') : __('New Carousel'),
            $id ? __('Edit Carousel') : __('New Carousel')
        );
        $resultPage->getConfig()->getTitle()->prepend(__('Carousels'));
        $resultPage->getConfig()->getTitle()->prepend($model->getId() ? __('Edit Carousel - %1', $model->getIdentifier()) : __('New Carousel'));
        return $resultPage;
    }
}

