<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * @category    Pinpoint
 * @copyright   Copyright (c) 2020 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Daniel Cuevas <daniel@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CarouselManager\Controller\Adminhtml\Slide;

use Magento\Framework\Exception\LocalizedException;
use Pinpoint\CarouselManager\Model\SlideFactory;

/**
 * Class SaveSlide
 */
class Save extends \Magento\Backend\App\Action
{

    protected $dataPersistor;
    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    private $resultJsonFactory;
    /**
     * @var SlideFactory
     */
    private $slideFactory;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\App\Request\DataPersistorInterface $dataPersistor
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        SlideFactory $slideFactory,
        \Magento\Framework\App\Request\DataPersistorInterface $dataPersistor
    ) {
        $this->dataPersistor = $dataPersistor;
        $this->resultJsonFactory = $resultJsonFactory;
        $this->slideFactory = $slideFactory;
        parent::__construct($context);
    }

    /**
     * Save action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $resultJson = $this->resultJsonFactory->create();

        $data = $this->getRequest()->getPostValue();
        if ($data) {
            try {

                $slide = $this->slideFactory->create();
                $slide->setData(
                    [
                        'title' => $data['new_slide_name'],
                        'cta_number' => $data['cta_number'],
                        'carousel_id' => $data['carousel_id']
                    ]
                );
                $slide->save();

            } catch (\Exception $e) {
                $resultJson->setData(['error' => $e->getMessage()]);
            }
        }

        $resultJson->setData(['success' => true]);
         return $resultJson;
    }
}
