<?php
/**
 * Copyright ©  All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Pinpoint\CarouselManager\Model;

use Magento\Framework\Api\DataObjectHelper;
use Pinpoint\CarouselManager\Api\Data\CarouselInterface;
use Pinpoint\CarouselManager\Api\Data\CarouselInterfaceFactory;

class Carousel extends \Magento\Framework\Model\AbstractModel
{

    protected $carouselDataFactory;

    protected $dataObjectHelper;

    protected $_eventPrefix = 'pinpoint_carouselmanager_carousel';
    /**
     * @var SlideRepository
     */
    private $slideRepository;

    /**
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param CarouselInterfaceFactory $carouselDataFactory
     * @param DataObjectHelper $dataObjectHelper
     * @param \Pinpoint\CarouselManager\Model\ResourceModel\Carousel $resource
     * @param \Pinpoint\CarouselManager\Model\ResourceModel\Carousel\Collection $resourceCollection
     * @param SlideRepository $slideRepository
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        CarouselInterfaceFactory $carouselDataFactory,
        DataObjectHelper $dataObjectHelper,
        \Pinpoint\CarouselManager\Model\ResourceModel\Carousel $resource,
        \Pinpoint\CarouselManager\Model\ResourceModel\Carousel\Collection $resourceCollection,
        SlideRepository $slideRepository,
        array $data = []
    ) {
        $this->carouselDataFactory = $carouselDataFactory;
        $this->dataObjectHelper = $dataObjectHelper;
        $this->slideRepository = $slideRepository;
        parent::__construct($context, $registry, $resource, $resourceCollection, $data);
    }

    /**
     * Retrieve carousel model with carousel data
     * @return CarouselInterface
     */
    public function getDataModel()
    {
        $carouselData = $this->getData();

        $carouselDataObject = $this->carouselDataFactory->create();
        $this->dataObjectHelper->populateWithArray(
            $carouselDataObject,
            $carouselData,
            CarouselInterface::class
        );

        return $carouselDataObject;
    }

    public function beforeSave()
    {
        $storeIds = $this->getStoreIds();
        if ($storeIds && is_array($storeIds)) {
            $storeIds = implode(',', $storeIds);
            $this->setStoreIds($storeIds);
        }
        return parent::beforeSave();
    }

    /**
     * @return mixed
     */
    public function afterLoad()
    {
        if ($storeIds = $this->getStoreIds()) {
            $this->setStoreIds(explode(',', $storeIds));
        }
        return parent::afterLoad();
    }

    /**
     * @return mixed
     */
    public function getFirstStoreId()
    {
        $storeIds = $this->getStoreIds();
        return $storeIds[0];
    }

    public function getSlides()
    {
        return $this->slideRepository->getByCarouselId($this->getId());
    }
}
